algolia_helper_flutter library
Algolia search helpers for Flutter
Provides patterns and APIs that make it possible to customize search experiences at a deeper level for Flutter framework.
Classes
- ClientOptions
- Configuration options for the HTTP client.
- CompositeDisposable
- Acts as a container for multiple disposables that can be canceled at once.
- Disposable
- Represents an object able to release it's resources.
- Facet
- A value of a given facet, together with its number of occurrences. Useful when an ordered list of facet values has to be presented to the user.
- FacetFilterGroup
- Filter group of FilterFacet filters.
- FacetList
- FacetList (refinement list) is a filtering components that displays facets, and lets the user refine their search results by filtering on specific values.
- FacetSearcher
- Algolia Helpers main entry point for facet search requests and managing search sessions.
- FacetSearchResponse
- Search for facet values operation response
- FacetSearchState
- Represents a search for facet values operation state, and an abstraction over facet search queries.
- Filter
- Represents a search filter:
- FilterFacet
- A FilterFacet matches exactly an attribute with a value. An optional score allows to assign a priority between several FilterFacet that are evaluated in the same filter group.
-
FilterGroup<
T extends Filter> - Represents a filter group, it is defined by a Set of Filters and a groupID.
- FilterGroupID
- Identifier of a filter group. The group name is for access purpose only, won't be used for the actual filters generation.
- FilterNumeric
- A FilterNumeric filters on a numeric value by range (lower/upper bounds) or by comparing it with NumericOperator.
- Filters
- Filter groups: facet, tag, numeric and hierarchical.
- FilterState
- FilterState holds one or several filters, organized in groups. filters streams filters changes of added or removed filters, which will be applied to searches performed by the connected Searcher.
- FilterTag
-
A FilterTag filters on a specific value.
It uses a reserved keywords
_tagsas attribute. - HierarchicalFilter
- Filter over a hierarchy of facet attributes.
- HierarchicalFilterGroup
- Filter group of hierarchical filters.
- HighlightableToken
-
Highlightable string token.
isHighlighted returning
trueindicates that content is highlighted. - HighlightedString
- Highlighted string as a list of tokens.
- Hit
- Represents search hit result
- HitsSearcher
- Algolia Helpers main entry point, the component handling search requests and managing search sessions.
- MultiSearcher
- Core component for multi-search requests and managing search sessions in Algolia Helpers.
- MultiSearcherDelegate
-
MultiSearcherDelegateserves as an abstract unit within the compositeMultiSearcher. It abstracts the underlying details of individual search units likeHitsSearcherandFacetSearcher, focusing primarily on exposing their states and providing mechanisms to update their responses. - MultiSearchResponse
- MultiSearchState
- NumericComparison
- Numeric comparison of a number using a NumericOperator.
- NumericFilterGroup
- Filter group of FilterNumeric filters.
- NumericRange
- Numeric range comprised within a lowerBound and an upperBound.
- NumericValue
- Represents a filter numeric value:
- SearchResponse
- Search operation response.
- SearchState
- Represents a search operation state, and an abstraction over search queries.
-
SelectableItem<
T> - Represents a value with selection status.
- SelectionState
-
The
SelectionStateabstract class represents a way to manage a selection state. - StatelessFilters
- Stateless (immutable) filters implementation. All operations create a new object with requested changes.
- TagFilterGroup
- Filter group of FilterTag filters.
Enums
- FilterOperator
- Group filter operator, can either be conjunctive (and) or disjunctive (or).
- NumericOperator
-
Numeric comparison operators.
Supported operators are:
<,<=,=,!=,>=and>. - SelectionMode
- Elements selection mode.
Extensions
-
FilterGroupMapExt
on FilterGroupMap<
T> - Extensions over FilterGroupMap.
- Highlightable on Hit
- Extension over Hit.
- HighlightableFacet on Facet
- Extension over Facet.
- HighlightingExt on HighlightedString
- Extension over HighlightedString.
- HitsSearcherFacetListExtension on HitsSearcher
- SearcherExt on HitsSearcher
- Extensions over HitsSearcher
Typedefs
-
AsyncFiltersBuilder
= Future<
StatelessFilters> Function(StatelessFilters filters) - Asynchronous stateless filters builder.
-
FilterGroupMap<
T> = Map< FilterGroupID, Set< T> > - Map of filter groups convenience type.
- ImmutableFilters = StatelessFilters
-
SelectableFacet
= SelectableItem<
Facet> - Facet with selection status.
Exceptions / Errors
- AlgoliaException
- Exception thrown when an error occurs during search operations.
- SearchError
- Exception thrown when an error occurs during search requests.